@@ -5,5 +5,7 @@ linearPredictors <- function( x, ... ) {
 linearPredictors.probit <- function( x, ... ) {
    mm <- naresid(na.action(x), model.matrix(x))
                            # naresid works (for now).  Should we keep it or replace it?
-   mm %*% x$estimate
+   result <- drop( mm %*% x$estimate )
+   names( result ) <- rownames( mm )
+   return( result )
 }
