@@ -1,6 +1,6 @@
 summary.probit <- function(object, ...) {
    ## summary for probit -- adds Likelihood Ratio Test to summary.maxLik
-   summaryML <- maxLik:::summary.maxLik(object, ...)
+   summaryML <- NextMethod( "summary", object, ...)
    pchi2 <- pchisq(object$LRT$LRT, object$LRT$df, lower.tail=FALSE)
    a <- c(summaryML,
           LRT=list(c(object$LRT, pchi2=pchi2)),
